@@ -56,7 +56,7 @@ static void parole_plugin_player_get_property (GObject *object,
 					       GParamSpec *pspec);
 
 #define PAROLE_PLUGIN_PLAYER_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE ((o), PAROLE_TYPE_PLUGINPLAYER, ParolePluginPlayerPrivate))
+(G_TYPE_INSTANCE_GET_PRIVATE ((o), PAROLE_TYPE_PLUGIN_PLAYER, ParolePluginPlayerPrivate))
 
 static GTimer *idle_timer = NULL;
 static GThread *idle_thread = NULL;
@@ -72,6 +72,7 @@ struct ParolePluginPlayerPrivate
     GtkWidget	 *range;
     GtkWidget    *full_screen;
     GtkWidget    *volume;
+    GtkWidget	 *buffering;
 
     ParoleScreenSaver *saver;
     
@@ -95,8 +96,30 @@ enum
     PROP_URL
 };
 
+enum
+{
+    SIG_ERROR,
+    SIG_FINISHED,
+    SIG_EXITING,
+    SIG_READY,
+    LAST_SIGNAL
+};
+
+static guint signals [LAST_SIGNAL] = { 0 };
+    
 G_DEFINE_TYPE (ParolePluginPlayer, parole_plugin_player, G_TYPE_OBJECT)
 
+static void
+parole_plugin_player_play (ParolePluginPlayer *player)
+{
+    if ( player->priv->terminate )
+	return;
+	
+    player->priv->reload = FALSE;
+    player->priv->finished = FALSE;
+    parole_gst_play_uri (player->priv->gst, player->priv->url, NULL);
+}
+
 static void
 parole_plugin_player_set_fullscreen_button (ParolePluginPlayer *player)
 {
@@ -253,7 +276,7 @@ parole_plugin_player_media_state_cb (ParoleGst *gst, const ParoleStream *stream,
     
     if ( state == PAROLE_MEDIA_STATE_PLAYING )
     {
-	gdouble duration;
+	gint64 duration;
 	gboolean seekable;
 	gboolean live;
 	
@@ -286,11 +309,17 @@ parole_plugin_player_media_state_cb (ParoleGst *gst, const ParoleStream *stream,
 	{
 	    parole_plugin_player_play (player);
 	}
+	else if ( player->priv->finished )
+	{
+	    player->priv->finished = FALSE;
+	    g_signal_emit (player, signals [SIG_FINISHED], 0);
+	}
     }
     else if ( state == PAROLE_MEDIA_STATE_FINISHED )
     {
 	parole_plugin_player_change_range_value (player, 0);
 	player->priv->finished = TRUE;
+	parole_gst_stop (PAROLE_GST (player->priv->gst));
     }
 }
 
@@ -347,7 +376,7 @@ parole_plugin_player_volume_changed_cb (GtkWidget *volume, gdouble value, Parole
 
 static void
 parole_plugin_player_media_progressed_cb (ParoleGst *gst, const ParoleStream *stream, 
-					  gdouble value, ParolePluginPlayer *player)
+					  gint64 value, ParolePluginPlayer *player)
 {
     
     if ( !player->priv->user_seeking && player->priv->state == PAROLE_MEDIA_STATE_PLAYING )
@@ -428,12 +457,6 @@ parole_plugin_player_gst_widget_button_release (GtkWidget *widget,
     return ret_val;
 }
 
-static void
-parole_plugin_player_error_cb (ParoleGst *gst, const gchar *error, ParolePluginPlayer *player)
-{
-    parole_screen_saver_uninhibit (player->priv->saver);
-}
-
 static void
 parole_plugin_player_fullscreen_clicked_cb (ParolePluginPlayer *player)
 {
@@ -481,6 +504,72 @@ parole_plugin_player_gst_widget_button_press (GtkWidget *widget, GdkEventButton
     return ret_val;
 }
 
+static gboolean
+parole_plugin_player_window_delete_event_cb (ParolePluginPlayer *player)
+{
+    parole_plugin_player_fullscreen (player, FALSE);
+    return TRUE;
+}
+
+static gpointer *check_idle_thread (gpointer data)
+{
+    ParolePluginPlayer *player;
+    
+    player = PAROLE_PLUGIN_PLAYER (data);
+    
+    do
+    {
+	g_usleep (1000000);
+	if ( g_timer_elapsed (idle_timer, NULL ) > 60.f )
+	{
+	    g_signal_emit (player, signals [SIG_EXITING], 0);
+	    gtk_main_quit ();
+	}
+	
+    } while ( player->priv->terminate == FALSE ); 
+
+    return NULL;
+}
+
+static void
+parole_plugin_player_dispose (GObject *object)
+{
+    ParolePluginPlayer *player;
+    
+    player = PAROLE_PLUGIN_PLAYER (object);
+    
+    g_signal_emit (player, signals [SIG_EXITING], 0);
+    
+    G_OBJECT_CLASS (parole_plugin_player_parent_class)->dispose (object);
+}
+
+static void
+parole_plugin_player_error_cb (ParoleGst *gst, const gchar *error, ParolePluginPlayer *player)
+{
+    player->priv->finished = TRUE;
+    parole_screen_saver_uninhibit (player->priv->saver);
+    parole_gst_stop (gst);
+}
+
+static void
+parole_plugin_player_buffering_cb (ParoleGst *gst, const ParoleStream *stream, 
+				   gint percentage, ParolePluginPlayer *player)
+{
+    if ( percentage == 100 )
+    {
+	gtk_widget_hide (player->priv->buffering);
+    }
+    else
+    {
+	gchar *text;
+	
+	text = g_strdup_printf ("%s %d%%...", _("Buffering"), percentage);
+	gtk_label_set_text (GTK_LABEL (player->priv->buffering), text);
+	g_free (text);
+	gtk_widget_show (player->priv->buffering);
+    }
+}
+
 static void
 parole_plugin_player_construct (GObject *object)
 {
@@ -507,6 +596,12 @@ parole_plugin_player_construct (GObject *object)
     g_signal_connect (G_OBJECT (player->priv->gst), "media-state",
 		      G_CALLBACK (parole_plugin_player_media_state_cb), player);
 
+    g_signal_connect (G_OBJECT (player->priv->gst), "error",
+		      G_CALLBACK (parole_plugin_player_error_cb), player);
+    
+    g_signal_connect (G_OBJECT (player->priv->gst), "buffering",
+		      G_CALLBACK (parole_plugin_player_buffering_cb), player);
+
     g_signal_connect (G_OBJECT (player->priv->gst), "media-progressed",
 		      G_CALLBACK (parole_plugin_player_media_progressed_cb), player);
 
@@ -608,6 +703,14 @@ parole_plugin_player_construct (GObject *object)
 		      G_CALLBACK (parole_plugin_player_volume_changed_cb), player);
     
     
+    /*
+     * buffering
+     */
+    player->priv->buffering = gtk_label_new (NULL);
+    gtk_widget_hide (player->priv->buffering);
+    gtk_box_pack_start (GTK_BOX (vbox), player->priv->buffering, 
+			FALSE, FALSE, 0);
+    
     gtk_box_pack_start (GTK_BOX (vbox), hbox, 
 			FALSE, FALSE, 0);
     gtk_container_add (GTK_CONTAINER (player->priv->plug), vbox);
@@ -619,35 +722,8 @@ parole_plugin_player_construct (GObject *object)
     gtk_widget_set_sensitive (player->priv->range, FALSE);
     
     player->priv->vbox = vbox;
-}
-
-static gboolean
-parole_plugin_player_window_delete_event_cb (ParolePluginPlayer *player)
-{
-    parole_plugin_player_fullscreen (player, FALSE);
-    return TRUE;
-}
-
-static gpointer *check_idle_thread (gpointer data)
-{
-    ParolePluginPlayer *player;
     
-    player = PAROLE_PLUGIN_PLAYER (data);
-    
-    do
-    {
-	g_usleep (1000000);
-	if ( g_timer_elapsed (idle_timer, NULL ) > 60.f )
-	{
-	    g_debug ("Idle timeout expired, exiting...");
-	    g_debug ("Here");
-	    gtk_main_quit ();
-	    g_debug ("Yalla");
-	}
-	
-    } while ( player->priv->terminate == FALSE ); 
-
-    return NULL;
+    g_signal_emit (player, signals [SIG_READY], 0);
 }
 
 static void
@@ -656,12 +732,49 @@ parole_plugin_player_class_init (ParolePluginPlayerClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
     object_class->finalize = parole_plugin_player_finalize;
+    object_class->dispose = parole_plugin_player_dispose;
 
     object_class->get_property = parole_plugin_player_get_property;
     object_class->set_property = parole_plugin_player_set_property;
 
     object_class->constructed = parole_plugin_player_construct;
     
+    signals[SIG_ERROR] = 
+        g_signal_new ("error",
+                      PAROLE_TYPE_PLUGIN_PLAYER,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParolePluginPlayerClass, error),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__VOID,
+                      G_TYPE_NONE, 0, G_TYPE_NONE);
+    
+    signals[SIG_FINISHED] = 
+        g_signal_new ("finished",
+                      PAROLE_TYPE_PLUGIN_PLAYER,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParolePluginPlayerClass, finished),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__VOID,
+                      G_TYPE_NONE, 0, G_TYPE_NONE);
+    
+    signals[SIG_EXITING] = 
+        g_signal_new ("exiting",
+                      PAROLE_TYPE_PLUGIN_PLAYER,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParolePluginPlayerClass, exiting),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__VOID,
+                      G_TYPE_NONE, 0, G_TYPE_NONE);
+    
+    signals[SIG_READY] = 
+        g_signal_new ("ready",
+                      PAROLE_TYPE_PLUGIN_PLAYER,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParolePluginPlayerClass, ready),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__VOID,
+                      G_TYPE_NONE, 0, G_TYPE_NONE);
+    
     
     g_object_class_install_property (object_class,
                                      PROP_PLUG,
@@ -783,6 +896,17 @@ parole_plugin_player_finalize (GObject *object)
     G_OBJECT_CLASS (parole_plugin_player_parent_class)->finalize (object);
 }
 
+static gboolean parole_plugin_player_play_idle (gpointer data)
+{
+    ParolePluginPlayer *player;
+    
+    player = PAROLE_PLUGIN_PLAYER (data);
+    
+    parole_plugin_player_play (player);
+    
+    return FALSE;
+}
+
 static gboolean
 parole_plugin_player_quit_idle (gpointer data)
 {
@@ -802,8 +926,8 @@ parole_plugin_player_stop_idle (gpointer data)
     
     player = PAROLE_PLUGIN_PLAYER (data);
     
-    if (player->priv->gst )
-	parole_gst_stop (player->priv->gst);
+    if (player->priv->gst)
+	parole_gst_terminate (player->priv->gst);
 	
     return FALSE;
 }
@@ -813,7 +937,7 @@ parole_plugin_player_new (GtkWidget *plug, gchar *url)
 {
     ParolePluginPlayer *player = NULL;
     
-    player = g_object_new (PAROLE_TYPE_PLUGINPLAYER, 
+    player = g_object_new (PAROLE_TYPE_PLUGIN_PLAYER, 
 			   "plug", plug, 
 			   "url", url, 
 			   NULL);
@@ -821,16 +945,6 @@ parole_plugin_player_new (GtkWidget *plug, gchar *url)
     return player;
 }
 
-void parole_plugin_player_play (ParolePluginPlayer *player)
-{
-    if ( player->priv->terminate )
-	return;
-	
-    player->priv->reload = FALSE;
-    player->priv->finished = FALSE;
-    parole_gst_play_uri (player->priv->gst, player->priv->url, NULL);
-}
-
 void parole_plugin_player_exit (ParolePluginPlayer *player)
 {
     player->priv->terminate = TRUE;
@@ -847,6 +961,10 @@ static gboolean parole_plugin_player_dbus_stop (ParolePluginPlayer *player,
 static gboolean parole_plugin_player_dbus_ping (ParolePluginPlayer *player,
 						GError **error);
 
+static gboolean parole_plugin_player_dbus_play_url (ParolePluginPlayer *player,
+						    gchar *in_URL,
+						    GError **error);
+
 #include "org.parole.media.plugin.h"
 
 /*
@@ -900,3 +1018,12 @@ static gboolean parole_plugin_player_dbus_ping (ParolePluginPlayer *player,
     return TRUE;
 }
 						
+static gboolean parole_plugin_player_dbus_play_url (ParolePluginPlayer *player,
+						    gchar *in_URL,
+						    GError **error)
+{
+    player->priv->url = g_strdup (in_URL);
+    g_debug ("Playing url=%s", in_URL);
+    g_idle_add ((GSourceFunc) parole_plugin_player_play_idle, player);
+    return TRUE;
+}
