@@ -39,6 +39,7 @@
 #include <gdk/gdkx.h>
 
 #include "parole-gst.h"
+#include "parole-gst-iface.h"
 
 #include "common/parole-common.h"
 
@@ -50,6 +51,8 @@
 #define PAROLE_GST_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((o), PAROLE_TYPE_GST, ParoleGstPrivate))
 
+static void     parole_gst_helper_iface_init    (ParoleGstHelperIface *iface);
+
 static void	parole_gst_play_file_internal 	(ParoleGst *gst);
 
 static void     parole_gst_change_state 	(ParoleGst *gst, 
@@ -81,7 +84,7 @@ struct ParoleGstPrivate
     
     gpointer      conf; /* Specific for ParoleMediaPlayer*/
     
-    
+    gboolean	  terminating;
     gboolean	  embedded;
     gboolean      enable_tags;
     
@@ -124,7 +127,8 @@ static gpointer parole_gst_object = NULL;
 
 static guint signals [LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (ParoleGst, parole_gst, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE_WITH_CODE (ParoleGst, parole_gst, GTK_TYPE_WIDGET,
+    G_IMPLEMENT_INTERFACE (PAROLE_TYPE_GST_HELPER, parole_gst_helper_iface_init));
 
 static void
 parole_gst_finalize (GObject *object)
@@ -154,6 +158,7 @@ parole_gst_finalize (GObject *object)
 static void
 parole_gst_set_window_cursor (GdkWindow *window, GdkCursor *cursor)
 {
+    TRACE ("start");
     if ( window )
         gdk_window_set_cursor (window, cursor);
 }
@@ -364,7 +369,7 @@ parole_gst_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 }
 
 static void
-parole_gst_draw_logo (ParoleGst *gst)
+parole_gst_draw_logo_common (ParoleGst *gst)
 {
     GdkPixbuf *pix;
     GdkRegion *region;
@@ -373,7 +378,7 @@ parole_gst_draw_logo (ParoleGst *gst)
 
     widget = GTK_WIDGET (gst);
 
-    if ( !widget->window )
+    if ( !widget->window)
 	return;
 
     rect.x = 0;
@@ -411,8 +416,30 @@ parole_gst_draw_logo (ParoleGst *gst)
 }
 
 static void
-parole_gst_set_video_color_balance (ParoleGst *gst)
+parole_gst_draw_logo_embedded (ParoleGstHelper *helper)
 {
+    ParoleGst *gst;
+    
+    gst = PAROLE_GST (helper);
+    
+    if ( !gst->priv->terminating )
+	parole_gst_draw_logo_common (gst);
+}
+
+static void
+parole_gst_draw_logo (ParoleGstHelper *helper)
+{
+    ParoleGst *gst;
+    
+    gst = PAROLE_GST (helper);
+    
+    parole_gst_draw_logo_common (gst);
+}
+
+static void
+parole_gst_set_video_color_balance (ParoleGstHelper *helper)
+{
+    ParoleGst *gst;
     GstElement *video_sink;
     
     gint brightness_value;
@@ -420,7 +447,9 @@ parole_gst_set_video_color_balance (ParoleGst *gst)
     gint hue_value;
     gint saturation_value;
 	
-    if ( !gst->priv->xvimage_sink || gst->priv->conf == NULL)
+    gst = PAROLE_GST (helper);
+    
+    if ( !gst->priv->xvimage_sink)
 	return;
 	
     g_object_get (G_OBJECT (gst->priv->playbin),
@@ -494,23 +523,23 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 	    if ( playing_video || gst->priv->with_vis)
 		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
 	    else
-		parole_gst_draw_logo (gst);
+		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    break;
 	case GST_STATE_PAUSED:
 	    if ( playing_video || gst->priv->with_vis || gst->priv->target == GST_STATE_PLAYING )
 		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
 	    else
-		parole_gst_draw_logo (gst);
+		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    break;
 	case GST_STATE_READY:
 	    if (gst->priv->with_vis == FALSE && gst->priv->target != GST_STATE_PLAYING)
-		parole_gst_draw_logo (gst);
+		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    else
 		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
 	    break;
 	case GST_STATE_NULL:
 	case GST_STATE_VOID_PENDING:
-	    parole_gst_draw_logo (gst);
+	    parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    break;
     }
     return TRUE;
@@ -533,8 +562,8 @@ parole_gst_tick_timeout (gpointer data)
     
     gint64 pos;
     GstFormat format = GST_FORMAT_TIME;
-    gdouble value;
-    gboolean video;
+    gint64 value;
+    gint64 video;
     
     gst = PAROLE_GST (data);
     
@@ -549,8 +578,10 @@ parole_gst_tick_timeout (gpointer data)
 
     if ( gst->priv->state == GST_STATE_PLAYING )
     {
-	value = ( pos / ((gdouble) 60 * 1000 * 1000 * 1000 ));
-	g_signal_emit (G_OBJECT (gst), signals [MEDIA_PROGRESSED], 0, gst->priv->stream, value);
+	value = pos / GST_SECOND;
+
+	if ( G_LIKELY (value > 0) )
+	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_PROGRESSED], 0, gst->priv->stream, value);
     }
 
 out:
@@ -604,7 +635,7 @@ static void
 parole_gst_query_duration (ParoleGst *gst)
 {
     gint64 absolute_duration = 0;
-    gdouble duration = 0;
+    gint64 duration = 0;
     gboolean live;
     GstFormat gst_time;
     
@@ -616,10 +647,10 @@ parole_gst_query_duration (ParoleGst *gst)
     
     if (gst_time == GST_FORMAT_TIME)
     {
-	duration =  absolute_duration / ((gdouble) 60 * 1000 * 1000 * 1000);
+	duration =  absolute_duration / GST_SECOND;
 	live = ( absolute_duration == 0 );
 	
-	TRACE ("Duration %e is_live=%d", duration, live);
+	TRACE ("Duration %lld is_live=%d", duration, live);
 	
 	g_object_set (G_OBJECT (gst->priv->stream),
 		      "absolute-duration", absolute_duration,
@@ -630,12 +661,12 @@ parole_gst_query_duration (ParoleGst *gst)
 }
 
 static void
-parole_gst_set_subtitle_font (ParoleGst *gst)
+parole_gst_set_subtitle_font (ParoleGstHelper *helper)
 {
+    ParoleGst *gst;
     gchar *font;
     
-    if ( !gst->priv->conf )
-	return;
+    gst = PAROLE_GST (helper);
     
     g_object_get (G_OBJECT (gst->priv->conf),
 		  "subtitle-font", &font,
@@ -650,12 +681,12 @@ parole_gst_set_subtitle_font (ParoleGst *gst)
 }
 
 static void
-parole_gst_set_subtitle_encoding (ParoleGst *gst)
+parole_gst_set_subtitle_encoding (ParoleGstHelper *helper)
 {
+    ParoleGst *gst;
     gchar *encoding;
     
-    if ( !gst->priv->conf )
-	return;
+    gst = PAROLE_GST (helper);
     
     g_object_get (G_OBJECT (gst->priv->conf),
 		  "subtitle-encoding", &encoding,
@@ -669,16 +700,16 @@ parole_gst_set_subtitle_encoding (ParoleGst *gst)
 }
 
 static void
-parole_gst_load_subtitle (ParoleGst *gst)
+parole_gst_load_subtitle (ParoleGstHelper *helper)
 {
+    ParoleGst *gst;
     ParoleMediaType type;
     gchar *uri;
     gchar *sub;
     gchar *sub_uri;
     gboolean sub_enabled;
     
-    if ( !gst->priv->conf )
-	return;
+    gst = PAROLE_GST (helper);
     
     g_object_get (G_OBJECT (gst->priv->stream),
 		  "media-type", &type,
@@ -832,14 +863,14 @@ parole_gst_update_stream_info (ParoleGst *gst)
 }
 
 static void
-parole_gst_update_vis (ParoleGst *gst)
+parole_gst_update_vis (ParoleGstHelper *helper)
 {
+    ParoleGst *gst;
     gchar *vis_name;
     
-    TRACE ("start");
+    gst = PAROLE_GST (helper);
     
-    if ( !gst->priv->conf )
-	return;
+    TRACE ("start");
     
     g_object_get (G_OBJECT (gst->priv->conf),
 		  "vis-enabled", &gst->priv->with_vis,
@@ -903,7 +934,7 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 	    if ( gst->priv->target == GST_STATE_PLAYING )
 	    {
 		if ( gst->priv->update_color_balance )
-		    parole_gst_set_video_color_balance (gst);
+		    parole_gst_helper_set_video_colors (PAROLE_GST_HELPER (gst));
 	    }
 		
 	    gst->priv->media_state = PAROLE_MEDIA_STATE_PAUSED;
@@ -912,9 +943,6 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 	    break;
 	case GST_STATE_READY:
 	    gst->priv->buffering = FALSE;
-	    if ( gst->priv->update_vis)
-		parole_gst_update_vis (gst);
-		
 	    gst->priv->media_state = PAROLE_MEDIA_STATE_STOPPED;
 	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_STATE], 0, 
 			   gst->priv->stream, PAROLE_MEDIA_STATE_STOPPED);
@@ -930,7 +958,7 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 	    else if ( gst->priv->target == GST_STATE_READY)
 	    {
 		parole_gst_size_allocate (GTK_WIDGET (gst), &GTK_WIDGET (gst)->allocation);
-		parole_gst_draw_logo (gst);
+		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    }
 	    break;
 	case GST_STATE_NULL:
@@ -1289,6 +1317,11 @@ parole_gst_play_file_internal (ParoleGst *gst)
 	TRACE ("*** Error *** This is a bug, playbin element is already playing");
     }
     
+    if ( gst->priv->update_vis)
+	parole_gst_helper_update_vis (PAROLE_GST_HELPER (gst));
+    
+    gtk_widget_queue_draw (GTK_WIDGET (gst));
+    
     g_object_get (G_OBJECT (gst->priv->stream),
 		  "uri", &uri,
 		  NULL);
@@ -1300,86 +1333,11 @@ parole_gst_play_file_internal (ParoleGst *gst)
 		  "suburi", NULL,
 		  NULL);
 
-    parole_gst_load_subtitle (gst);
+    parole_gst_helper_load_subtitle (PAROLE_GST_HELPER (gst));
     parole_gst_change_state (gst, GST_STATE_PLAYING);
-    
     g_free (uri);
 }
 
-static void
-parole_gst_construct (GObject *object)
-{
-    ParoleGst *gst;
-    
-    gst = PAROLE_GST (object);
-    
-    gst->priv->playbin = gst_element_factory_make ("playbin", "player");
- 
-    if ( G_UNLIKELY (gst->priv->playbin == NULL) )
-    {
-	xfce_err (_("Unable to load playbin GStreamer plugin"
-		    ", check your GStreamer installation"));
-		    
-	g_error ("playbin load failed");
-    }
-    
-    gst->priv->video_sink = gst_element_factory_make ("xvimagesink", "video");
-    gst->priv->xvimage_sink = TRUE;
-    if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
-    {
-	gst->priv->xvimage_sink = FALSE;
-	g_debug ("xvimagesink not found, trying to load ximagesink"); 
-	gst->priv->video_sink = gst_element_factory_make ("ximagesink", "video");
-	
-	if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
-	{
-	    xfce_err (_("Unable to load video GStreamer plugin"
-		      ", check your GStreamer installation"));
-	    g_error ("ximagesink load failed");
-	}
-    }
-    
-    parole_gst_update_vis (gst);
-    
-    g_object_set (G_OBJECT (gst->priv->playbin),
-		  "video-sink", gst->priv->video_sink,
-		  NULL);
-    
-    /*
-     * Listen to the bus events.
-     */
-    gst->priv->bus = gst_element_get_bus (gst->priv->playbin);
-    gst_bus_add_signal_watch (gst->priv->bus);
-    
-    gst->priv->sig1 =
-	g_signal_connect (gst->priv->bus, "message",
-			  G_CALLBACK (parole_gst_bus_event), gst);
-		      
-    /* 
-     * Handling 'prepare-xwindow-id' message async causes XSync 
-     * error in some occasions So we handle this message synchronously
-     */
-    gst_bus_set_sync_handler (gst->priv->bus, gst_bus_sync_signal_handler, gst);
-    gst->priv->sig2 =
-	g_signal_connect (gst->priv->bus, "sync-message::element",
-			  G_CALLBACK (parole_gst_element_message_sync), gst);
-
-    /*
-     * Handle stream info changes, this can happen on live/radio stream.
-     */
-    g_signal_connect (gst->priv->playbin, "notify::stream-info",
-		      G_CALLBACK (parole_gst_stream_info_notify_cb), gst);
-      
-      
-    g_signal_connect (gst->priv->playbin, "notify::source",
-		      G_CALLBACK (parole_gst_source_notify_cb), gst);
-
-    parole_gst_load_logo (gst);
-    parole_gst_set_subtitle_encoding (gst);
-    parole_gst_set_subtitle_font (gst);
-    TRACE ("End");
-}
-
 static gboolean
 parole_gst_motion_notify_event (GtkWidget *widget, GdkEventMotion *ev)
 {
@@ -1491,7 +1449,7 @@ parole_gst_change_dvd_chapter (ParoleGst *gst, gint level)
 {
     GstFormat format;
 
-    // FIXME: Do we really need to get the nich each time?
+    // FIXME: Do we really need to get the nick each time?
     format = gst_format_get_by_nick ("chapter");
     
     parole_gst_seek_by_format (gst, format, level);
@@ -1556,6 +1514,9 @@ parole_gst_terminate_internal (ParoleGst *gst, gboolean fade_sound)
 
     parole_window_busy_cursor (GTK_WIDGET (gst)->window);
     
+    if ( gst->priv->embedded )
+	goto out;
+    
     if ( fade_sound && gst->priv->state == GST_STATE_PLAYING && !playing_video )
     {
 	gdouble volume;
@@ -1576,6 +1537,7 @@ parole_gst_terminate_internal (ParoleGst *gst, gboolean fade_sound)
 	}
     }
     
+out:
     parole_gst_change_state (gst, GST_STATE_NULL);
 }
 
@@ -1588,11 +1550,11 @@ parole_gst_conf_notify_cb (GObject *object, GParamSpec *spec, ParoleGst *gst)
     }
     else if ( !g_strcmp0 ("subtitle-font", spec->name) || !g_strcmp0 ("enable-subtitle", spec->name)  )
     {
-	parole_gst_set_subtitle_font (gst);
+	parole_gst_helper_set_subtitle_font (PAROLE_GST_HELPER (gst));
     }
     else if (!g_strcmp0 ("subtitle-encoding", spec->name) )
     {
-	parole_gst_set_subtitle_encoding (gst);
+	parole_gst_helper_set_subtitle_encoding (PAROLE_GST_HELPER (gst));
     }
     else if ( !g_strcmp0 ("brightness", spec->name) || !g_strcmp0 ("hue", spec->name) ||
 	      !g_strcmp0 ("contrast", spec->name) || !g_strcmp0 ("saturation", spec->name) )
@@ -1600,7 +1562,7 @@ parole_gst_conf_notify_cb (GObject *object, GParamSpec *spec, ParoleGst *gst)
 	gst->priv->update_color_balance = TRUE;
 	
 	if ( gst->priv->state >= GST_STATE_PAUSED )
-	    parole_gst_set_video_color_balance (gst);
+	    parole_gst_helper_set_video_colors (PAROLE_GST_HELPER (gst));
     }
     else if ( !g_strcmp0 ("aspect-ratio", spec->name) )
     {
@@ -1673,6 +1635,108 @@ static void parole_gst_set_property (GObject *object,
     }
 }
 
+static void parole_gst_helper_iface_init (ParoleGstHelperIface *iface)
+{
+}
+
+static void
+parole_gst_set_iface_methods (ParoleGst *gst)
+{
+    ParoleGstHelperIface *iface;
+    iface = PAROLE_GST_HELPER_GET_IFACE (gst);
+	
+    if ( gst->priv->embedded == FALSE)
+    {
+	iface->draw_logo = parole_gst_draw_logo;
+	iface->set_video_color_balance = parole_gst_set_video_color_balance;
+	iface->set_subtitle_encoding = parole_gst_set_subtitle_encoding;
+	iface->set_subtitle_font = parole_gst_set_subtitle_font;
+	iface->load_subtitle = parole_gst_load_subtitle;
+	iface->update_vis = parole_gst_update_vis;
+    }
+    else
+    {
+	iface->draw_logo = parole_gst_draw_logo_embedded;
+    }
+}
+
+static void
+parole_gst_constructed (GObject *object)
+{
+    ParoleGst *gst;
+    
+    gst = PAROLE_GST (object);
+    
+    gst->priv->playbin = gst_element_factory_make ("playbin", "player");
+ 
+    if ( G_UNLIKELY (gst->priv->playbin == NULL) )
+    {
+	xfce_err (_("Unable to load playbin GStreamer plugin"
+		    ", check your GStreamer installation"));
+		    
+	g_error ("playbin load failed");
+    }
+    
+    gst->priv->video_sink = gst_element_factory_make ("xvimagesink", "video");
+    gst->priv->xvimage_sink = TRUE;
+    if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
+    {
+	gst->priv->xvimage_sink = FALSE;
+	g_debug ("xvimagesink not found, trying to load ximagesink"); 
+	gst->priv->video_sink = gst_element_factory_make ("ximagesink", "video");
+	
+	if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
+	{
+	    xfce_err (_("Unable to load video GStreamer plugin"
+		      ", check your GStreamer installation"));
+	    g_error ("ximagesink load failed");
+	}
+    }
+    
+    g_object_set (G_OBJECT (gst->priv->playbin),
+		  "video-sink", gst->priv->video_sink,
+		  NULL);
+    
+    /*
+     * Listen to the bus events.
+     */
+    gst->priv->bus = gst_element_get_bus (gst->priv->playbin);
+    gst_bus_add_signal_watch (gst->priv->bus);
+    
+    gst->priv->sig1 =
+	g_signal_connect (gst->priv->bus, "message",
+			  G_CALLBACK (parole_gst_bus_event), gst);
+		      
+    /* 
+     * Handling 'prepare-xwindow-id' message async causes XSync 
+     * error in some occasions So we handle this message synchronously
+     */
+    gst_bus_set_sync_handler (gst->priv->bus, gst_bus_sync_signal_handler, gst);
+    gst->priv->sig2 =
+	g_signal_connect (gst->priv->bus, "sync-message::element",
+			  G_CALLBACK (parole_gst_element_message_sync), gst);
+
+    /*
+     * Handle stream info changes, this can happen on live/radio stream.
+     */
+    g_signal_connect (gst->priv->playbin, "notify::stream-info",
+		      G_CALLBACK (parole_gst_stream_info_notify_cb), gst);
+      
+      
+    g_signal_connect (gst->priv->playbin, "notify::source",
+		      G_CALLBACK (parole_gst_source_notify_cb), gst);
+
+    
+    parole_gst_set_iface_methods (gst);
+
+    parole_gst_helper_update_vis (PAROLE_GST_HELPER (gst));
+    parole_gst_load_logo (gst);
+    parole_gst_helper_set_subtitle_encoding (PAROLE_GST_HELPER (gst));
+    parole_gst_helper_set_subtitle_font (PAROLE_GST_HELPER (gst));
+    
+    TRACE ("End");
+}
+
 static void
 parole_gst_class_init (ParoleGstClass *klass)
 {
@@ -1680,7 +1744,7 @@ parole_gst_class_init (ParoleGstClass *klass)
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     object_class->finalize = parole_gst_finalize;
-    object_class->constructed = parole_gst_construct;
+    object_class->constructed = parole_gst_constructed;
     object_class->set_property = parole_gst_set_property;
     object_class->get_property = parole_gst_get_property;
 
@@ -1708,9 +1772,9 @@ parole_gst_class_init (ParoleGstClass *klass)
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (ParoleGstClass, media_progressed),
                       NULL, NULL,
-                      _gmarshal_VOID__OBJECT_DOUBLE,
+                      _gmarshal_VOID__OBJECT_INT64,
                       G_TYPE_NONE, 2, 
-		      G_TYPE_OBJECT, G_TYPE_DOUBLE);
+		      G_TYPE_OBJECT, G_TYPE_INT64);
     
     signals [MEDIA_TAG] = 
         g_signal_new ("media-tag",
@@ -1771,7 +1835,7 @@ static void
 parole_gst_init (ParoleGst *gst)
 {
     gst->priv = PAROLE_GST_GET_PRIVATE (gst);
-    
+
     gst->priv->state = GST_STATE_VOID_PENDING;
     gst->priv->target = GST_STATE_VOID_PENDING;
     gst->priv->media_state = PAROLE_MEDIA_STATE_STOPPED;
@@ -1787,6 +1851,7 @@ parole_gst_init (ParoleGst *gst)
     gst->priv->state_change_id = 0;
     gst->priv->device = NULL;
     gst->priv->enable_tags = TRUE;
+    gst->priv->terminating = FALSE;
     
     gst->priv->conf = NULL;
     
@@ -1938,6 +2003,7 @@ void parole_gst_stop (ParoleGst *gst)
 
 void parole_gst_terminate (ParoleGst *gst)
 {
+    gst->priv->terminating = TRUE;
     parole_gst_terminate_internal (gst, TRUE);
 }
 
@@ -1960,7 +2026,7 @@ void parole_gst_seek (ParoleGst *gst, gdouble pos)
 {
     gint64 seek;
     gint64 absolute_duration;
-    gdouble duration;
+    gint64 duration;
     gboolean seekable;
 
     TRACE ("Seeking");
@@ -1977,7 +2043,7 @@ void parole_gst_seek (ParoleGst *gst, gdouble pos)
     g_return_if_fail (seekable == TRUE);
 #endif
 	
-    seek = (gint64) (pos * absolute_duration) / duration;
+    seek = (pos * absolute_duration) / duration;
     
     g_warn_if_fail ( gst_element_seek (gst->priv->playbin,
 				       1.0,
@@ -2065,9 +2131,9 @@ gint parole_gst_get_current_cdda_track (ParoleGst *gst)
     return ret_val;
 }
 
-gdouble	parole_gst_get_stream_duration (ParoleGst *gst)
+gint64	parole_gst_get_stream_duration (ParoleGst *gst)
 {
-    gdouble dur;
+    gint64 dur;
     
     g_object_get (G_OBJECT (gst->priv->stream),
 		  "duration", &dur,
@@ -2075,17 +2141,14 @@ gdouble	parole_gst_get_stream_duration (ParoleGst *gst)
     return dur;
 }
 
-gdouble parole_gst_get_stream_position (ParoleGst *gst)
+gint64 parole_gst_get_stream_position (ParoleGst *gst)
 {
     GstFormat format = GST_FORMAT_TIME;
-    gdouble value;
     gint64 pos;
     
     gst_element_query_position (gst->priv->playbin, &format, &pos);
     
-    value = ( pos / ((gdouble) 60 * 1000 * 1000 * 1000 ));
-    
-    return value;
+    return  pos / GST_SECOND;
 }
 
 gboolean parole_gst_get_is_xvimage_sink (ParoleGst *gst)
