@@ -260,10 +260,13 @@ parole_media_list_files_open (ParoleMediaList *list, GSList *files,
 }
 
 static void
-parole_media_list_files_opened_cb (ParoleMediaChooser *chooser, gboolean replace,
-				   GSList *files, ParoleMediaList *list)
+parole_media_list_files_opened_cb (ParoleMediaChooser *chooser, 
+				   gboolean play,
+				   gboolean replace,
+				   GSList *files, 
+				   ParoleMediaList *list)
 {
-    parole_media_list_files_open (list, files, replace, TRUE);
+    parole_media_list_files_open (list, files, replace, play);
 }
 
 static void
@@ -448,7 +451,7 @@ void parole_media_list_save_playlist_cb (GtkButton *button, ParolePlaylistSave *
     
     parole_media_list_close_save_dialog_cb (NULL, data);
     
-    parole_pl_parser_save_file (list, filename, format);
+    parole_pl_parser_save_from_files (list, filename, format);
     g_slist_free (list);
 out:
     g_free (filename);
@@ -1083,10 +1086,10 @@ void parole_media_list_load (ParoleMediaList *list)
 						     FALSE);
 	if ( playlist_file )
 	{
-	    fileslist = parole_pl_parser_load_file (playlist_file);
+	    fileslist = parole_pl_parser_parse_from_file_by_extension (playlist_file);
 	    g_free (playlist_file);
 	    
-	    parole_media_list_files_opened_cb (NULL, FALSE, fileslist, list);
+	    parole_media_list_files_opened_cb (NULL, FALSE, FALSE, fileslist, list);
 	    g_slist_free (fileslist);
 	}
     }
@@ -1320,7 +1323,7 @@ void parole_media_list_save_list (ParoleMediaList *list)
 	fileslist = parole_media_list_get_files (list);
 	if ( g_slist_length (fileslist) > 0 )
 	{
-	    parole_pl_parser_save_file (fileslist, history, PAROLE_PL_FORMAT_M3U);
+	    parole_pl_parser_save_from_files (fileslist, history, PAROLE_PL_FORMAT_M3U);
 	    g_slist_foreach (fileslist, (GFunc) g_object_unref, NULL);
 	}
 	g_slist_free (fileslist);
